#ifndef NT2_INCLUDE_FUNCTIONS_MAXMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAXMAG_HPP_INCLUDED

#include <nt2/ieee/include/functions/maxmag.hpp>

#endif
